@@ -1,6 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Peter Müller   *
- *   pmueller@cs.tu-berlin.de   *
+ *   Copyright (C) 2005 by Peter Müller                                    *
+ *   pmueller@cs.tu-berlin.de                                              *
+ *   Copyright (C) 2008 by John Stamp <jstamp@users.sourceforge.net>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -15,7 +16,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
  ***************************************************************************/
 
 #ifndef GLOBAL_H
@@ -34,9 +35,9 @@
 #include <list>
 #include <cassert>
 
-using namespace std;
+#define VERSION "1.0.4"
 
-extern GLuint *textures;
+using namespace std;
 
 enum {
 	T_PARTICLE,
@@ -45,29 +46,6 @@ enum {
 	T_NUM,
 };
 
-struct Setting {
-	int intValue;
-	double doubleValue;
-};
-
-extern Setting* config;
-
-enum {
-	SE_COLORS,
-	SE_CREATEINTERVAL,
-	SE_DOMATRIX,
-	SE_DOSLOWMOTION,
-	SE_DOBLITZ,
-	SE_DOSPLITCOMET,
-	SE_DOCURVECOMET,
-	SE_DOROTATECOMET,
-	SE_FREECAMERA,
-	SE_FREECAMERASPEED,
-	SE_TIMESCALE,
-	SE_SIZESCALE,
-	SE_NUM,
-};
-
 enum {
 	C_RED,
 	C_BLUE,
